
<div class="title-body" style="height: 566px; width: 652px;">
  <div class="title-header">
  <span style="font-size: 12.5424px; line-height: 16.5424px;">МІНІСТЕРСТВО ОСВІТИ І НАУКИ УКРАЇНИ</span><span style="font-size: 12.5424px; line-height: 16.5424px;">ВИЩИЙ НАВЧАЛЬНИЙ ЗАКЛАД</span>
  </div>
  <div class="img-header-block" style="background-image: url(http://www.surgpu.ru/media/uploads/2016/10/04/cropped-biznes-informatika.jpg)">
  <div class="opacity-header-block">
  
  </div>
  </div>
  <div class="autor-block">
  <div class="autor-border">
  <span style="font-size: 15.3408px; line-height: 19.3408px;"> {{cc.authors}}</span>
  </div>
  </div>
  <div class="book-name-block">
  <span class="book-name" style="font-size: 26.6288px; line-height: 30.6288px;"> {{cc.name}}</span><span class="book-type" style="font-size: 18.1864px; line-height: 22.1864px;">{{cc.type}}</span>
  </div>
  <div class="title-footer">
  <p><img src="../logo-org.png"></p>
  <span style="font-size: 14.7984px;">{{cc.city_year}}</span>
  </div>
  </div>
